@@ -41,17 +41,19 @@
 
 (ert-deftest yaml-parsing-scalar ()
   "Test conversion of !!str to JSON scalar"
-  (should (equal :null (yaml--resolve-scalar-tag "null")))
-  (should (equal :false (yaml--resolve-scalar-tag "false")))
-  (should (equal t (yaml--resolve-scalar-tag "true")))
-  (should (equal "xtruex" (yaml--resolve-scalar-tag "xtruex")))
-  (should (equal 0 (yaml--resolve-scalar-tag "0")))
-  (should (equal 10 (yaml--resolve-scalar-tag "10")))
-  (should (equal "x10" (yaml--resolve-scalar-tag "x10")))
-  (should (equal 10.52 (yaml--resolve-scalar-tag "10.52")))
-  (should (equal 52.0 (yaml--resolve-scalar-tag ".52e2")))
-  (should (equal 1.0e+INF (yaml--resolve-scalar-tag ".Inf")))
-  (should (equal "hello world" (yaml--resolve-scalar-tag "hello world"))))
+  (let* ((yaml--parsing-null-object :null)
+         (yaml--parsing-false-object :false))
+    (should (equal :null (yaml--resolve-scalar-tag "null")))
+    (should (equal :false (yaml--resolve-scalar-tag "false")))
+    (should (equal t (yaml--resolve-scalar-tag "true")))
+    (should (equal "xtruex" (yaml--resolve-scalar-tag "xtruex")))
+    (should (equal 0 (yaml--resolve-scalar-tag "0")))
+    (should (equal 10 (yaml--resolve-scalar-tag "10")))
+    (should (equal "x10" (yaml--resolve-scalar-tag "x10")))
+    (should (equal 10.52 (yaml--resolve-scalar-tag "10.52")))
+    (should (equal 52.0 (yaml--resolve-scalar-tag ".52e2")))
+    (should (equal 1.0e+INF (yaml--resolve-scalar-tag ".Inf")))
+    (should (equal "hello world" (yaml--resolve-scalar-tag "hello world")))))
 
 (ert-deftest yaml-process-literal-text-test ()
   "Test processing literal strings"
@@ -417,7 +419,11 @@ ship-to:
                  "this is text"))
   (should (equal (yaml-parse-string "top: |1\n  this is text"
                                     :object-type 'alist)
-                 '((top . " this is text\n")))))
+                 '((top . " this is text\n"))))
+  (should (equal (yaml-parse-string "top: 0x10" :object-type 'alist)
+                 '((top . 16))))
+  (should (equal (yaml-parse-string "top: 0o10" :object-type 'alist)
+                 '((top . 8)))))
 
 (ert-deftest yaml-parsing-completes ()
   "Tests that the yaml parses."
@@ -615,10 +621,10 @@ keep: |+
            "[1, 2, 3]"))
   (should (equal
            (yaml-encode `[((foo . bar) (baz . bax))])
-           "\n- foo: bar\n  baz: bax"))
+           "- foo: bar\n  baz: bax"))
   (should (equal
            (yaml-encode `((deeper . [((foo . bar) (baz . bax))])))
-           "\ndeeper: \n- foo: bar\n  baz: bax"))
+           "deeper: \n- foo: bar\n  baz: bax"))
   (should (equal (yaml-parse-string
                   (yaml-encode [1 [2 [3] 2] 1])
                   :object-type 'alist
